#include <iostream>
#include <fstream>
#include <sstream>
#include <vector>
#include <iomanip>

using namespace std;

// Define struct for student
struct Student {
    string code;
    string name;
    double weighted_average;
};

// Function prototypes
vector<string> readFromFile(const string& filename);
vector<Student> processData(const vector<string>& data);
void writeToFile(const string& filename, const vector<Student>& students);

int main() {
    vector<string> data = readFromFile("F1.txt");
    vector<Student> students = processData(data);
    writeToFile("F2.txt", students); 
    return 0;
}

// Function to read data from file and return vector of lines
vector<string> readFromFile(const string& filename) {
    ifstream file(filename);
    vector<string> data;
    if (file.is_open()) {
        string line;
        while (getline(file, line)) {
            data.push_back(line);
        }
        file.close();
    } else {
        cerr << "Unable to open file " << filename << endl;
        exit(1);
    }
    return data;
}

// Function to process data from vector of lines and return vector of Students
vector<Student> processData(const vector<string>& data) {
    vector<Student> students;

    for (const auto& line : data) {
        stringstream ss(line);
        Student student;

        // Read student code and name
        ss >> student.code >> student.name;

        // Variables for calculating weighted average
        double sum = 0;
        double total_eap = 0;
        double grade, eap;

        // Read grades and EAP
        while (ss >> grade >> eap) {
            sum += grade * eap; 
            total_eap += eap;
        }

        // Calculate weighted average if total_eap is not zero
        if (total_eap != 0) {
            student.weighted_average = sum / total_eap;
            students.push_back(student);
        }
    }

    return students;
}

// Function to write data to file
void writeToFile(const string& filename, const vector<Student>& students) {
    ofstream file(filename);
    if (file.is_open()) {
        for (const auto& student : students) {
            file << student.code << ", " << student.name << ", " << fixed << setprecision(1) << student.weighted_average << endl;
        }
        file.close();
    } else {
        cerr << "Unable to open file " << filename << endl;
        exit(1);
    }
}
